qermit.frame_randomisation
==========================

.. automethod:: qermit.frame_randomisation.frame_randomisation.gen_Frame_Randomisation_MitRes

.. autoclass:: qermit.frame_randomisation.frame_randomisation.FrameRandomisation
    :members:
    :special-members:

.. automethod:: qermit.frame_randomisation.frame_randomisation.frame_randomisation_circuits_task_gen

.. automethod:: qermit.frame_randomisation.frame_randomisation.frame_randomisation_result_task_gen
